diff --git a/.github/build/full.json b/.github/build/full.json
index 69743931de..b43ffab681 100644
--- a/.github/build/full.json
+++ b/.github/build/full.json
@@ -2,7 +2,7 @@
"modules": {
"authorize": {
"repository": "simplesamlphp/simplesamlphp-module-authorize",
- "version": "~1.6.1"
+ "version": "~1.6.2"
},
"consent": {
"repository": "simplesamlphp/simplesamlphp-module-consent",
diff --git a/composer.json b/composer.json
index dd6959df8f..7a2dba587b 100644
--- a/composer.json
+++ b/composer.json
@@ -123,12 +123,12 @@
},
"extra": {
"branch-alias": {
- "dev-master": "2.4.0.x-dev"
+ "dev-master": "2.3.0.x-dev"
}
},
"scripts": {
"translations:unused": "php bin/translations translations:unused",
"translations:update:translatable": "php bin/translations translations:update:translatable"
},
- "version": "v2.3.8"
+ "version": "v2.3.9"
}
diff --git a/composer.lock b/composer.lock
index beff2e3f01..0476ab51ac 100644
--- a/composer.lock
+++ b/composer.lock
@@ -4,7 +4,7 @@
"Read more about it at https://getcomposer.org/doc/01-basic-usage.md#installing-dependencies",
"This file is @generated automatically"
],
- "content-hash": "d5a4c080ba45815db6d946b9838add1d",
+ "content-hash": "1c542a41895188d7f62c695353926ce8",
"packages": [
{
"name": "gettext/gettext",
@@ -347,16 +347,16 @@
},
{
"name": "phpmailer/phpmailer",
- "version": "v6.10.0",
+ "version": "v6.11.1",
"source": {
"type": "git",
"url": "https://github.com/PHPMailer/PHPMailer.git",
- "reference": "bf74d75a1fde6beaa34a0ddae2ec5fce0f72a144"
+ "reference": "d9e3b36b47f04b497a0164c5a20f92acb4593284"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/PHPMailer/PHPMailer/zipball/bf74d75a1fde6beaa34a0ddae2ec5fce0f72a144",
- "reference": "bf74d75a1fde6beaa34a0ddae2ec5fce0f72a144",
+ "url": "https://api.github.com/repos/PHPMailer/PHPMailer/zipball/d9e3b36b47f04b497a0164c5a20f92acb4593284",
+ "reference": "d9e3b36b47f04b497a0164c5a20f92acb4593284",
"shasum": ""
},
"require": {
@@ -377,6 +377,7 @@
},
"suggest": {
"decomplexity/SendOauth2": "Adapter for using XOAUTH2 authentication",
+ "ext-imap": "Needed to support advanced email address parsing according to RFC822",
"ext-mbstring": "Needed to send email in multibyte encoding charset or decode encoded addresses",
"ext-openssl": "Needed for secure SMTP sending and DKIM signing",
"greew/oauth2-azure-provider": "Needed for Microsoft Azure XOAUTH2 authentication",
@@ -416,7 +417,7 @@
"description": "PHPMailer is a full-featured email creation and transfer class for PHP",
"support": {
"issues": "https://github.com/PHPMailer/PHPMailer/issues",
- "source": "https://github.com/PHPMailer/PHPMailer/tree/v6.10.0"
+ "source": "https://github.com/PHPMailer/PHPMailer/tree/v6.11.1"
},
"funding": [
{
@@ -424,7 +425,7 @@
"type": "github"
}
],
- "time": "2025-04-24T15:19:31+00:00"
+ "time": "2025-09-30T11:54:53+00:00"
},
{
"name": "psr/cache",
@@ -824,16 +825,16 @@
},
{
"name": "simplesamlphp/assert",
- "version": "v1.8.1",
+ "version": "v1.8.2",
"source": {
"type": "git",
"url": "https://github.com/simplesamlphp/assert.git",
- "reference": "f35e26e1201ec41be19404e23f87e53cf747ed3a"
+ "reference": "b551f50399540172f387d97b2e7246e6c352154d"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/simplesamlphp/assert/zipball/f35e26e1201ec41be19404e23f87e53cf747ed3a",
- "reference": "f35e26e1201ec41be19404e23f87e53cf747ed3a",
+ "url": "https://api.github.com/repos/simplesamlphp/assert/zipball/b551f50399540172f387d97b2e7246e6c352154d",
+ "reference": "b551f50399540172f387d97b2e7246e6c352154d",
"shasum": ""
},
"require": {
@@ -841,13 +842,13 @@
"ext-filter": "*",
"ext-pcre": "*",
"ext-spl": "*",
- "guzzlehttp/psr7": "~2.7.0",
+ "guzzlehttp/psr7": "~2.7.1",
"php": "^8.1",
"webmozart/assert": "~1.11.0"
},
"require-dev": {
"ext-intl": "*",
- "simplesamlphp/simplesamlphp-test-framework": "~1.8.0"
+ "simplesamlphp/simplesamlphp-test-framework": "~1.9.2"
},
"type": "library",
"extra": {
@@ -877,9 +878,9 @@
"description": "A wrapper around webmozart/assert to make it useful beyond checking method arguments",
"support": {
"issues": "https://github.com/simplesamlphp/assert/issues",
- "source": "https://github.com/simplesamlphp/assert/tree/v1.8.1"
+ "source": "https://github.com/simplesamlphp/assert/tree/v1.8.2"
},
- "time": "2025-01-09T12:10:04+00:00"
+ "time": "2025-06-28T12:57:30+00:00"
},
{
"name": "simplesamlphp/composer-module-installer",
@@ -924,18 +925,60 @@
},
"time": "2025-03-19T20:38:37+00:00"
},
+ {
+ "name": "simplesamlphp/composer-xmlprovider-installer",
+ "version": "v1.0.2",
+ "source": {
+ "type": "git",
+ "url": "https://github.com/simplesamlphp/composer-xmlprovider-installer.git",
+ "reference": "3d882187b5b0b404c381a2e4d17498ca4b2785b3"
+ },
+ "dist": {
+ "type": "zip",
+ "url": "https://api.github.com/repos/simplesamlphp/composer-xmlprovider-installer/zipball/3d882187b5b0b404c381a2e4d17498ca4b2785b3",
+ "reference": "3d882187b5b0b404c381a2e4d17498ca4b2785b3",
+ "shasum": ""
+ },
+ "require": {
+ "composer-plugin-api": "^2.0",
+ "php": "^8.1"
+ },
+ "require-dev": {
+ "composer/composer": "^2.4",
+ "simplesamlphp/simplesamlphp-test-framework": "^1.5.4"
+ },
+ "type": "composer-plugin",
+ "extra": {
+ "class": "SimpleSAML\\Composer\\XMLProvider\\XMLProviderInstallerPlugin"
+ },
+ "autoload": {
+ "psr-4": {
+ "SimpleSAML\\Composer\\XMLProvider\\": "src/"
+ }
+ },
+ "notification-url": "https://packagist.org/downloads/",
+ "license": [
+ "LGPL-2.1-only"
+ ],
+ "description": "A composer plugin that will auto-generate a classmap with all classes that implement SerializableElementInterface.",
+ "support": {
+ "issues": "https://github.com/simplesamlphp/composer-xmlprovider-installer/issues",
+ "source": "https://github.com/simplesamlphp/composer-xmlprovider-installer/tree/v1.0.2"
+ },
+ "time": "2025-06-28T18:54:25+00:00"
+ },
{
"name": "simplesamlphp/saml2",
- "version": "v4.18.1",
+ "version": "v4.19.0",
"source": {
"type": "git",
"url": "https://github.com/simplesamlphp/saml2.git",
- "reference": "78b1c6735db8e2f78dcea9bcac0317ad2b200d72"
+ "reference": "a1e25f1351591c2b007449735c0e62e016696576"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/simplesamlphp/saml2/zipball/78b1c6735db8e2f78dcea9bcac0317ad2b200d72",
- "reference": "78b1c6735db8e2f78dcea9bcac0317ad2b200d72",
+ "url": "https://api.github.com/repos/simplesamlphp/saml2/zipball/a1e25f1351591c2b007449735c0e62e016696576",
+ "reference": "a1e25f1351591c2b007449735c0e62e016696576",
"shasum": ""
},
"require": {
@@ -981,22 +1024,22 @@
"description": "SAML2 PHP library from SimpleSAMLphp",
"support": {
"issues": "https://github.com/simplesamlphp/saml2/issues",
- "source": "https://github.com/simplesamlphp/saml2/tree/v4.18.1"
+ "source": "https://github.com/simplesamlphp/saml2/tree/v4.19.0"
},
- "time": "2025-03-16T11:37:44+00:00"
+ "time": "2025-09-05T23:47:51+00:00"
},
{
"name": "simplesamlphp/simplesamlphp-assets-base",
- "version": "v2.3.9",
+ "version": "v2.3.11",
"source": {
"type": "git",
"url": "https://github.com/simplesamlphp/simplesamlphp-assets-base.git",
- "reference": "75bd31897ed3634d97de2815b5fa668625f8134d"
+ "reference": "c852ea06c436222ec3e942122d4cec9f8661ba70"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/simplesamlphp/simplesamlphp-assets-base/zipball/75bd31897ed3634d97de2815b5fa668625f8134d",
- "reference": "75bd31897ed3634d97de2815b5fa668625f8134d",
+ "url": "https://api.github.com/repos/simplesamlphp/simplesamlphp-assets-base/zipball/c852ea06c436222ec3e942122d4cec9f8661ba70",
+ "reference": "c852ea06c436222ec3e942122d4cec9f8661ba70",
"shasum": ""
},
"require": {
@@ -1017,22 +1060,22 @@
"description": "Assets for the SimpleSAMLphp main repository",
"support": {
"issues": "https://github.com/simplesamlphp/simplesamlphp-assets-base/issues",
- "source": "https://github.com/simplesamlphp/simplesamlphp-assets-base/tree/v2.3.9"
+ "source": "https://github.com/simplesamlphp/simplesamlphp-assets-base/tree/v2.3.11"
},
- "time": "2025-03-02T17:54:55+00:00"
+ "time": "2025-09-18T17:06:32+00:00"
},
{
"name": "simplesamlphp/xml-common",
- "version": "v1.25.0",
+ "version": "v1.25.1",
"source": {
"type": "git",
"url": "https://github.com/simplesamlphp/xml-common.git",
- "reference": "2250c05aa0062bba4baad9d2357e94f9aa10ffc0"
+ "reference": "999603aa521d91e17b562bb0b498513af80eb190"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/simplesamlphp/xml-common/zipball/2250c05aa0062bba4baad9d2357e94f9aa10ffc0",
- "reference": "2250c05aa0062bba4baad9d2357e94f9aa10ffc0",
+ "url": "https://api.github.com/repos/simplesamlphp/xml-common/zipball/999603aa521d91e17b562bb0b498513af80eb190",
+ "reference": "999603aa521d91e17b562bb0b498513af80eb190",
"shasum": ""
},
"require": {
@@ -1044,6 +1087,7 @@
"ext-spl": "*",
"php": "^8.1",
"simplesamlphp/assert": "~1.8.1",
+ "simplesamlphp/composer-xmlprovider-installer": "~1.0.2",
"symfony/finder": "~6.4.0"
},
"require-dev": {
@@ -1079,20 +1123,20 @@
"issues": "https://github.com/simplesamlphp/xml-common/issues",
"source": "https://github.com/simplesamlphp/xml-common"
},
- "time": "2025-06-02T21:40:38+00:00"
+ "time": "2025-06-29T13:05:44+00:00"
},
{
"name": "simplesamlphp/xml-security",
- "version": "v1.13.2",
+ "version": "v1.13.7",
"source": {
"type": "git",
"url": "https://github.com/simplesamlphp/xml-security.git",
- "reference": "a7f2e09632da1179ecb9a021c3c2fbcbcd28071a"
+ "reference": "f6f32a3c2c6b398408d5bccc9d59445edc1cb67d"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/simplesamlphp/xml-security/zipball/a7f2e09632da1179ecb9a021c3c2fbcbcd28071a",
- "reference": "a7f2e09632da1179ecb9a021c3c2fbcbcd28071a",
+ "url": "https://api.github.com/repos/simplesamlphp/xml-security/zipball/f6f32a3c2c6b398408d5bccc9d59445edc1cb67d",
+ "reference": "f6f32a3c2c6b398408d5bccc9d59445edc1cb67d",
"shasum": ""
},
"require": {
@@ -1141,22 +1185,22 @@
],
"support": {
"issues": "https://github.com/simplesamlphp/xml-security/issues",
- "source": "https://github.com/simplesamlphp/xml-security/tree/v1.13.2"
+ "source": "https://github.com/simplesamlphp/xml-security/tree/v1.13.7"
},
- "time": "2025-06-04T21:49:04+00:00"
+ "time": "2025-06-29T13:07:27+00:00"
},
{
"name": "symfony/cache",
- "version": "v6.4.21",
+ "version": "v6.4.26",
"source": {
"type": "git",
"url": "https://github.com/symfony/cache.git",
- "reference": "d1abcf763a7414f2e572f676f22da7a06c8cd9ee"
+ "reference": "66c853ddcbf85c1984169869be498c3e7597b367"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/cache/zipball/d1abcf763a7414f2e572f676f22da7a06c8cd9ee",
- "reference": "d1abcf763a7414f2e572f676f22da7a06c8cd9ee",
+ "url": "https://api.github.com/repos/symfony/cache/zipball/66c853ddcbf85c1984169869be498c3e7597b367",
+ "reference": "66c853ddcbf85c1984169869be498c3e7597b367",
"shasum": ""
},
"require": {
@@ -1223,7 +1267,7 @@
"psr6"
],
"support": {
- "source": "https://github.com/symfony/cache/tree/v6.4.21"
+ "source": "https://github.com/symfony/cache/tree/v6.4.26"
},
"funding": [
{
@@ -1234,12 +1278,16 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2025-04-08T08:21:20+00:00"
+ "time": "2025-09-11T09:57:09+00:00"
},
{
"name": "symfony/cache-contracts",
@@ -1319,16 +1367,16 @@
},
{
"name": "symfony/config",
- "version": "v6.4.22",
+ "version": "v6.4.26",
"source": {
"type": "git",
"url": "https://github.com/symfony/config.git",
- "reference": "af5917a3b1571f54689e56677a3f06440d2fe4c7"
+ "reference": "f18dc5926cb203e125956987def795d052ee774e"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/config/zipball/af5917a3b1571f54689e56677a3f06440d2fe4c7",
- "reference": "af5917a3b1571f54689e56677a3f06440d2fe4c7",
+ "url": "https://api.github.com/repos/symfony/config/zipball/f18dc5926cb203e125956987def795d052ee774e",
+ "reference": "f18dc5926cb203e125956987def795d052ee774e",
"shasum": ""
},
"require": {
@@ -1374,7 +1422,7 @@
"description": "Helps you find, load, combine, autofill and validate configuration values of any kind",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/config/tree/v6.4.22"
+ "source": "https://github.com/symfony/config/tree/v6.4.26"
},
"funding": [
{
@@ -1385,25 +1433,29 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2025-05-14T06:00:01+00:00"
+ "time": "2025-09-11T09:57:09+00:00"
},
{
"name": "symfony/console",
- "version": "v6.4.22",
+ "version": "v6.4.26",
"source": {
"type": "git",
"url": "https://github.com/symfony/console.git",
- "reference": "7d29659bc3c9d8e9a34e2c3414ef9e9e003e6cf3"
+ "reference": "492de6dfd93910d7d7a729c5a04ddcd2b9e99c4f"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/console/zipball/7d29659bc3c9d8e9a34e2c3414ef9e9e003e6cf3",
- "reference": "7d29659bc3c9d8e9a34e2c3414ef9e9e003e6cf3",
+ "url": "https://api.github.com/repos/symfony/console/zipball/492de6dfd93910d7d7a729c5a04ddcd2b9e99c4f",
+ "reference": "492de6dfd93910d7d7a729c5a04ddcd2b9e99c4f",
"shasum": ""
},
"require": {
@@ -1468,7 +1520,7 @@
"terminal"
],
"support": {
- "source": "https://github.com/symfony/console/tree/v6.4.22"
+ "source": "https://github.com/symfony/console/tree/v6.4.26"
},
"funding": [
{
@@ -1479,25 +1531,29 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2025-05-07T07:05:04+00:00"
+ "time": "2025-09-26T12:13:46+00:00"
},
{
"name": "symfony/dependency-injection",
- "version": "v6.4.22",
+ "version": "v6.4.26",
"source": {
"type": "git",
"url": "https://github.com/symfony/dependency-injection.git",
- "reference": "8cb11f833d1f5bfbb2df97dfc23c92b4d42c18d9"
+ "reference": "5f311eaf0b321f8ec640f6bae12da43a14026898"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/dependency-injection/zipball/8cb11f833d1f5bfbb2df97dfc23c92b4d42c18d9",
- "reference": "8cb11f833d1f5bfbb2df97dfc23c92b4d42c18d9",
+ "url": "https://api.github.com/repos/symfony/dependency-injection/zipball/5f311eaf0b321f8ec640f6bae12da43a14026898",
+ "reference": "5f311eaf0b321f8ec640f6bae12da43a14026898",
"shasum": ""
},
"require": {
@@ -1549,7 +1605,7 @@
"description": "Allows you to standardize and centralize the way objects are constructed in your application",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/dependency-injection/tree/v6.4.22"
+ "source": "https://github.com/symfony/dependency-injection/tree/v6.4.26"
},
"funding": [
{
@@ -1560,12 +1616,16 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2025-05-17T07:35:26+00:00"
+ "time": "2025-09-11T09:57:09+00:00"
},
{
"name": "symfony/deprecation-contracts",
@@ -1636,16 +1696,16 @@
},
{
"name": "symfony/error-handler",
- "version": "v6.4.22",
+ "version": "v6.4.26",
"source": {
"type": "git",
"url": "https://github.com/symfony/error-handler.git",
- "reference": "ce765a2d28b3cce61de1fb916e207767a73171d1"
+ "reference": "41bedcaec5b72640b0ec2096547b75fda72ead6c"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/error-handler/zipball/ce765a2d28b3cce61de1fb916e207767a73171d1",
- "reference": "ce765a2d28b3cce61de1fb916e207767a73171d1",
+ "url": "https://api.github.com/repos/symfony/error-handler/zipball/41bedcaec5b72640b0ec2096547b75fda72ead6c",
+ "reference": "41bedcaec5b72640b0ec2096547b75fda72ead6c",
"shasum": ""
},
"require": {
@@ -1691,7 +1751,7 @@
"description": "Provides tools to manage errors and ease debugging PHP code",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/error-handler/tree/v6.4.22"
+ "source": "https://github.com/symfony/error-handler/tree/v6.4.26"
},
"funding": [
{
@@ -1702,25 +1762,29 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2025-05-28T12:00:15+00:00"
+ "time": "2025-09-11T09:57:09+00:00"
},
{
"name": "symfony/event-dispatcher",
- "version": "v6.4.13",
+ "version": "v6.4.25",
"source": {
"type": "git",
"url": "https://github.com/symfony/event-dispatcher.git",
- "reference": "0ffc48080ab3e9132ea74ef4e09d8dcf26bf897e"
+ "reference": "b0cf3162020603587363f0551cd3be43958611ff"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/event-dispatcher/zipball/0ffc48080ab3e9132ea74ef4e09d8dcf26bf897e",
- "reference": "0ffc48080ab3e9132ea74ef4e09d8dcf26bf897e",
+ "url": "https://api.github.com/repos/symfony/event-dispatcher/zipball/b0cf3162020603587363f0551cd3be43958611ff",
+ "reference": "b0cf3162020603587363f0551cd3be43958611ff",
"shasum": ""
},
"require": {
@@ -1771,7 +1835,7 @@
"description": "Provides tools that allow your application components to communicate with each other by dispatching events and listening to them",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/event-dispatcher/tree/v6.4.13"
+ "source": "https://github.com/symfony/event-dispatcher/tree/v6.4.25"
},
"funding": [
{
@@ -1782,12 +1846,16 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2024-09-25T14:18:03+00:00"
+ "time": "2025-08-13T09:41:44+00:00"
},
{
"name": "symfony/event-dispatcher-contracts",
@@ -1867,16 +1935,16 @@
},
{
"name": "symfony/filesystem",
- "version": "v6.4.13",
+ "version": "v6.4.24",
"source": {
"type": "git",
"url": "https://github.com/symfony/filesystem.git",
- "reference": "4856c9cf585d5a0313d8d35afd681a526f038dd3"
+ "reference": "75ae2edb7cdcc0c53766c30b0a2512b8df574bd8"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/filesystem/zipball/4856c9cf585d5a0313d8d35afd681a526f038dd3",
- "reference": "4856c9cf585d5a0313d8d35afd681a526f038dd3",
+ "url": "https://api.github.com/repos/symfony/filesystem/zipball/75ae2edb7cdcc0c53766c30b0a2512b8df574bd8",
+ "reference": "75ae2edb7cdcc0c53766c30b0a2512b8df574bd8",
"shasum": ""
},
"require": {
@@ -1913,7 +1981,7 @@
"description": "Provides basic utilities for the filesystem",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/filesystem/tree/v6.4.13"
+ "source": "https://github.com/symfony/filesystem/tree/v6.4.24"
},
"funding": [
{
@@ -1924,25 +1992,29 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2024-10-25T15:07:50+00:00"
+ "time": "2025-07-10T08:14:14+00:00"
},
{
"name": "symfony/finder",
- "version": "v6.4.17",
+ "version": "v6.4.24",
"source": {
"type": "git",
"url": "https://github.com/symfony/finder.git",
- "reference": "1d0e8266248c5d9ab6a87e3789e6dc482af3c9c7"
+ "reference": "73089124388c8510efb8d2d1689285d285937b08"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/finder/zipball/1d0e8266248c5d9ab6a87e3789e6dc482af3c9c7",
- "reference": "1d0e8266248c5d9ab6a87e3789e6dc482af3c9c7",
+ "url": "https://api.github.com/repos/symfony/finder/zipball/73089124388c8510efb8d2d1689285d285937b08",
+ "reference": "73089124388c8510efb8d2d1689285d285937b08",
"shasum": ""
},
"require": {
@@ -1977,7 +2049,7 @@
"description": "Finds files and directories via an intuitive fluent interface",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/finder/tree/v6.4.17"
+ "source": "https://github.com/symfony/finder/tree/v6.4.24"
},
"funding": [
{
@@ -1988,25 +2060,29 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2024-12-29T13:51:37+00:00"
+ "time": "2025-07-15T12:02:45+00:00"
},
{
"name": "symfony/framework-bundle",
- "version": "v6.4.22",
+ "version": "v6.4.26",
"source": {
"type": "git",
"url": "https://github.com/symfony/framework-bundle.git",
- "reference": "b1de19b2083484d0ce945977f6c6484e9e493a2e"
+ "reference": "e16f6ddaf8f026d5f3323f3bbc0660654ccdd837"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/framework-bundle/zipball/b1de19b2083484d0ce945977f6c6484e9e493a2e",
- "reference": "b1de19b2083484d0ce945977f6c6484e9e493a2e",
+ "url": "https://api.github.com/repos/symfony/framework-bundle/zipball/e16f6ddaf8f026d5f3323f3bbc0660654ccdd837",
+ "reference": "e16f6ddaf8f026d5f3323f3bbc0660654ccdd837",
"shasum": ""
},
"require": {
@@ -2126,7 +2202,7 @@
"description": "Provides a tight integration between Symfony components and the Symfony full-stack framework",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/framework-bundle/tree/v6.4.22"
+ "source": "https://github.com/symfony/framework-bundle/tree/v6.4.26"
},
"funding": [
{
@@ -2137,25 +2213,29 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2025-05-14T07:14:36+00:00"
+ "time": "2025-09-16T07:32:45+00:00"
},
{
"name": "symfony/http-foundation",
- "version": "v6.4.22",
+ "version": "v6.4.26",
"source": {
"type": "git",
"url": "https://github.com/symfony/http-foundation.git",
- "reference": "6b7c97fe1ddac8df3cc9ba6410c8abc683e148ae"
+ "reference": "369241591d92bb5dfb4c6ccd6ee94378a45b1521"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/http-foundation/zipball/6b7c97fe1ddac8df3cc9ba6410c8abc683e148ae",
- "reference": "6b7c97fe1ddac8df3cc9ba6410c8abc683e148ae",
+ "url": "https://api.github.com/repos/symfony/http-foundation/zipball/369241591d92bb5dfb4c6ccd6ee94378a45b1521",
+ "reference": "369241591d92bb5dfb4c6ccd6ee94378a45b1521",
"shasum": ""
},
"require": {
@@ -2203,7 +2283,7 @@
"description": "Defines an object-oriented layer for the HTTP specification",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/http-foundation/tree/v6.4.22"
+ "source": "https://github.com/symfony/http-foundation/tree/v6.4.26"
},
"funding": [
{
@@ -2214,25 +2294,29 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2025-05-11T15:36:20+00:00"
+ "time": "2025-09-16T08:22:30+00:00"
},
{
"name": "symfony/http-kernel",
- "version": "v6.4.22",
+ "version": "v6.4.26",
"source": {
"type": "git",
"url": "https://github.com/symfony/http-kernel.git",
- "reference": "15c105b839a7cfa1bc0989c091bfb6477f23b673"
+ "reference": "8b0f963293aede77593c9845c8c0af34752e893a"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/http-kernel/zipball/15c105b839a7cfa1bc0989c091bfb6477f23b673",
- "reference": "15c105b839a7cfa1bc0989c091bfb6477f23b673",
+ "url": "https://api.github.com/repos/symfony/http-kernel/zipball/8b0f963293aede77593c9845c8c0af34752e893a",
+ "reference": "8b0f963293aede77593c9845c8c0af34752e893a",
"shasum": ""
},
"require": {
@@ -2317,7 +2401,7 @@
"description": "Provides a structured process for converting a Request into a Response",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/http-kernel/tree/v6.4.22"
+ "source": "https://github.com/symfony/http-kernel/tree/v6.4.26"
},
"funding": [
{
@@ -2328,25 +2412,29 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2025-05-29T07:23:40+00:00"
+ "time": "2025-09-27T12:20:56+00:00"
},
{
"name": "symfony/intl",
- "version": "v6.4.22",
+ "version": "v6.4.26",
"source": {
"type": "git",
"url": "https://github.com/symfony/intl.git",
- "reference": "aaecb52f18a6f95766a239ca0a6cc0df983d92cc"
+ "reference": "0cd11e99e8c505f7ee7c6f0ccc8bccb8e14e652f"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/intl/zipball/aaecb52f18a6f95766a239ca0a6cc0df983d92cc",
- "reference": "aaecb52f18a6f95766a239ca0a6cc0df983d92cc",
+ "url": "https://api.github.com/repos/symfony/intl/zipball/0cd11e99e8c505f7ee7c6f0ccc8bccb8e14e652f",
+ "reference": "0cd11e99e8c505f7ee7c6f0ccc8bccb8e14e652f",
"shasum": ""
},
"require": {
@@ -2400,7 +2488,7 @@
"localization"
],
"support": {
- "source": "https://github.com/symfony/intl/tree/v6.4.22"
+ "source": "https://github.com/symfony/intl/tree/v6.4.26"
},
"funding": [
{
@@ -2411,25 +2499,29 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2025-05-04T12:02:38+00:00"
+ "time": "2025-09-07T21:26:26+00:00"
},
{
"name": "symfony/password-hasher",
- "version": "v6.4.13",
+ "version": "v6.4.24",
"source": {
"type": "git",
"url": "https://github.com/symfony/password-hasher.git",
- "reference": "e97a1b31f60b8bdfc1fdedab4398538da9441d47"
+ "reference": "dcab5ac87450aaed26483ba49c2ce86808da7557"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/password-hasher/zipball/e97a1b31f60b8bdfc1fdedab4398538da9441d47",
- "reference": "e97a1b31f60b8bdfc1fdedab4398538da9441d47",
+ "url": "https://api.github.com/repos/symfony/password-hasher/zipball/dcab5ac87450aaed26483ba49c2ce86808da7557",
+ "reference": "dcab5ac87450aaed26483ba49c2ce86808da7557",
"shasum": ""
},
"require": {
@@ -2472,7 +2564,7 @@
"password"
],
"support": {
- "source": "https://github.com/symfony/password-hasher/tree/v6.4.13"
+ "source": "https://github.com/symfony/password-hasher/tree/v6.4.24"
},
"funding": [
{
@@ -2483,16 +2575,20 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2024-09-25T14:18:03+00:00"
+ "time": "2025-07-10T08:14:14+00:00"
},
{
"name": "symfony/polyfill-ctype",
- "version": "v1.32.0",
+ "version": "v1.33.0",
"source": {
"type": "git",
"url": "https://github.com/symfony/polyfill-ctype.git",
@@ -2551,7 +2647,7 @@
"portable"
],
"support": {
- "source": "https://github.com/symfony/polyfill-ctype/tree/v1.32.0"
+ "source": "https://github.com/symfony/polyfill-ctype/tree/v1.33.0"
},
"funding": [
{
@@ -2562,6 +2658,10 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
@@ -2571,16 +2671,16 @@
},
{
"name": "symfony/polyfill-intl-grapheme",
- "version": "v1.32.0",
+ "version": "v1.33.0",
"source": {
"type": "git",
"url": "https://github.com/symfony/polyfill-intl-grapheme.git",
- "reference": "b9123926e3b7bc2f98c02ad54f6a4b02b91a8abe"
+ "reference": "380872130d3a5dd3ace2f4010d95125fde5d5c70"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/polyfill-intl-grapheme/zipball/b9123926e3b7bc2f98c02ad54f6a4b02b91a8abe",
- "reference": "b9123926e3b7bc2f98c02ad54f6a4b02b91a8abe",
+ "url": "https://api.github.com/repos/symfony/polyfill-intl-grapheme/zipball/380872130d3a5dd3ace2f4010d95125fde5d5c70",
+ "reference": "380872130d3a5dd3ace2f4010d95125fde5d5c70",
"shasum": ""
},
"require": {
@@ -2629,7 +2729,7 @@
"shim"
],
"support": {
- "source": "https://github.com/symfony/polyfill-intl-grapheme/tree/v1.32.0"
+ "source": "https://github.com/symfony/polyfill-intl-grapheme/tree/v1.33.0"
},
"funding": [
{
@@ -2640,25 +2740,29 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2024-09-09T11:45:10+00:00"
+ "time": "2025-06-27T09:58:17+00:00"
},
{
"name": "symfony/polyfill-intl-icu",
- "version": "v1.32.0",
+ "version": "v1.33.0",
"source": {
"type": "git",
"url": "https://github.com/symfony/polyfill-intl-icu.git",
- "reference": "763d2a91fea5681509ca01acbc1c5e450d127811"
+ "reference": "bfc8fa13dbaf21d69114b0efcd72ab700fb04d0c"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/polyfill-intl-icu/zipball/763d2a91fea5681509ca01acbc1c5e450d127811",
- "reference": "763d2a91fea5681509ca01acbc1c5e450d127811",
+ "url": "https://api.github.com/repos/symfony/polyfill-intl-icu/zipball/bfc8fa13dbaf21d69114b0efcd72ab700fb04d0c",
+ "reference": "bfc8fa13dbaf21d69114b0efcd72ab700fb04d0c",
"shasum": ""
},
"require": {
@@ -2713,7 +2817,7 @@
"shim"
],
"support": {
- "source": "https://github.com/symfony/polyfill-intl-icu/tree/v1.32.0"
+ "source": "https://github.com/symfony/polyfill-intl-icu/tree/v1.33.0"
},
"funding": [
{
@@ -2724,16 +2828,20 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2024-12-21T18:38:29+00:00"
+ "time": "2025-06-20T22:24:30+00:00"
},
{
"name": "symfony/polyfill-intl-normalizer",
- "version": "v1.32.0",
+ "version": "v1.33.0",
"source": {
"type": "git",
"url": "https://github.com/symfony/polyfill-intl-normalizer.git",
@@ -2794,7 +2902,7 @@
"shim"
],
"support": {
- "source": "https://github.com/symfony/polyfill-intl-normalizer/tree/v1.32.0"
+ "source": "https://github.com/symfony/polyfill-intl-normalizer/tree/v1.33.0"
},
"funding": [
{
@@ -2805,6 +2913,10 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
@@ -2814,7 +2926,7 @@
},
{
"name": "symfony/polyfill-mbstring",
- "version": "v1.32.0",
+ "version": "v1.33.0",
"source": {
"type": "git",
"url": "https://github.com/symfony/polyfill-mbstring.git",
@@ -2875,7 +2987,7 @@
"shim"
],
"support": {
- "source": "https://github.com/symfony/polyfill-mbstring/tree/v1.32.0"
+ "source": "https://github.com/symfony/polyfill-mbstring/tree/v1.33.0"
},
"funding": [
{
@@ -2886,6 +2998,10 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
@@ -2895,16 +3011,16 @@
},
{
"name": "symfony/polyfill-php83",
- "version": "v1.32.0",
+ "version": "v1.33.0",
"source": {
"type": "git",
"url": "https://github.com/symfony/polyfill-php83.git",
- "reference": "2fb86d65e2d424369ad2905e83b236a8805ba491"
+ "reference": "17f6f9a6b1735c0f163024d959f700cfbc5155e5"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/polyfill-php83/zipball/2fb86d65e2d424369ad2905e83b236a8805ba491",
- "reference": "2fb86d65e2d424369ad2905e83b236a8805ba491",
+ "url": "https://api.github.com/repos/symfony/polyfill-php83/zipball/17f6f9a6b1735c0f163024d959f700cfbc5155e5",
+ "reference": "17f6f9a6b1735c0f163024d959f700cfbc5155e5",
"shasum": ""
},
"require": {
@@ -2951,7 +3067,7 @@
"shim"
],
"support": {
- "source": "https://github.com/symfony/polyfill-php83/tree/v1.32.0"
+ "source": "https://github.com/symfony/polyfill-php83/tree/v1.33.0"
},
"funding": [
{
@@ -2962,25 +3078,29 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2024-09-09T11:45:10+00:00"
+ "time": "2025-07-08T02:45:35+00:00"
},
{
"name": "symfony/routing",
- "version": "v6.4.22",
+ "version": "v6.4.26",
"source": {
"type": "git",
"url": "https://github.com/symfony/routing.git",
- "reference": "1f5234e8457164a3a0038a4c0a4ba27876a9c670"
+ "reference": "6fc4c445f22857d4b8b40a02b73f423ddab295de"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/routing/zipball/1f5234e8457164a3a0038a4c0a4ba27876a9c670",
- "reference": "1f5234e8457164a3a0038a4c0a4ba27876a9c670",
+ "url": "https://api.github.com/repos/symfony/routing/zipball/6fc4c445f22857d4b8b40a02b73f423ddab295de",
+ "reference": "6fc4c445f22857d4b8b40a02b73f423ddab295de",
"shasum": ""
},
"require": {
@@ -3034,7 +3154,7 @@
"url"
],
"support": {
- "source": "https://github.com/symfony/routing/tree/v6.4.22"
+ "source": "https://github.com/symfony/routing/tree/v6.4.26"
},
"funding": [
{
@@ -3045,12 +3165,16 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2025-04-27T16:08:38+00:00"
+ "time": "2025-09-11T09:57:09+00:00"
},
{
"name": "symfony/service-contracts",
@@ -3137,16 +3261,16 @@
},
{
"name": "symfony/string",
- "version": "v6.4.21",
+ "version": "v6.4.26",
"source": {
"type": "git",
"url": "https://github.com/symfony/string.git",
- "reference": "73e2c6966a5aef1d4892873ed5322245295370c6"
+ "reference": "5621f039a71a11c87c106c1c598bdcd04a19aeea"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/string/zipball/73e2c6966a5aef1d4892873ed5322245295370c6",
- "reference": "73e2c6966a5aef1d4892873ed5322245295370c6",
+ "url": "https://api.github.com/repos/symfony/string/zipball/5621f039a71a11c87c106c1c598bdcd04a19aeea",
+ "reference": "5621f039a71a11c87c106c1c598bdcd04a19aeea",
"shasum": ""
},
"require": {
@@ -3160,7 +3284,6 @@
"symfony/translation-contracts": "<2.5"
},
"require-dev": {
- "symfony/error-handler": "^5.4|^6.0|^7.0",
"symfony/http-client": "^5.4|^6.0|^7.0",
"symfony/intl": "^6.2|^7.0",
"symfony/translation-contracts": "^2.5|^3.0",
@@ -3203,7 +3326,7 @@
"utf8"
],
"support": {
- "source": "https://github.com/symfony/string/tree/v6.4.21"
+ "source": "https://github.com/symfony/string/tree/v6.4.26"
},
"funding": [
{
@@ -3214,12 +3337,16 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2025-04-18T15:23:29+00:00"
+ "time": "2025-09-11T14:32:46+00:00"
},
{
"name": "symfony/translation-contracts",
@@ -3301,16 +3428,16 @@
},
{
"name": "symfony/twig-bridge",
- "version": "v6.4.22",
+ "version": "v6.4.25",
"source": {
"type": "git",
"url": "https://github.com/symfony/twig-bridge.git",
- "reference": "04ab306a2f2c9dbd46f4363383812954f704af9d"
+ "reference": "9d13e87591c9de3221c8d6f23cd9a2b5958607bf"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/twig-bridge/zipball/04ab306a2f2c9dbd46f4363383812954f704af9d",
- "reference": "04ab306a2f2c9dbd46f4363383812954f704af9d",
+ "url": "https://api.github.com/repos/symfony/twig-bridge/zipball/9d13e87591c9de3221c8d6f23cd9a2b5958607bf",
+ "reference": "9d13e87591c9de3221c8d6f23cd9a2b5958607bf",
"shasum": ""
},
"require": {
@@ -3390,7 +3517,7 @@
"description": "Provides integration for Twig with various Symfony components",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/twig-bridge/tree/v6.4.22"
+ "source": "https://github.com/symfony/twig-bridge/tree/v6.4.25"
},
"funding": [
{
@@ -3401,25 +3528,29 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2025-05-16T08:23:44+00:00"
+ "time": "2025-08-13T09:41:44+00:00"
},
{
"name": "symfony/var-dumper",
- "version": "v6.4.21",
+ "version": "v6.4.26",
"source": {
"type": "git",
"url": "https://github.com/symfony/var-dumper.git",
- "reference": "22560f80c0c5cd58cc0bcaf73455ffd81eb380d5"
+ "reference": "cfae1497a2f1eaad78dbc0590311c599c7178d4a"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/var-dumper/zipball/22560f80c0c5cd58cc0bcaf73455ffd81eb380d5",
- "reference": "22560f80c0c5cd58cc0bcaf73455ffd81eb380d5",
+ "url": "https://api.github.com/repos/symfony/var-dumper/zipball/cfae1497a2f1eaad78dbc0590311c599c7178d4a",
+ "reference": "cfae1497a2f1eaad78dbc0590311c599c7178d4a",
"shasum": ""
},
"require": {
@@ -3431,7 +3562,6 @@
"symfony/console": "<5.4"
},
"require-dev": {
- "ext-iconv": "*",
"symfony/console": "^5.4|^6.0|^7.0",
"symfony/error-handler": "^6.3|^7.0",
"symfony/http-kernel": "^5.4|^6.0|^7.0",
@@ -3475,7 +3605,7 @@
"dump"
],
"support": {
- "source": "https://github.com/symfony/var-dumper/tree/v6.4.21"
+ "source": "https://github.com/symfony/var-dumper/tree/v6.4.26"
},
"funding": [
{
@@ -3486,25 +3616,29 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2025-04-09T07:34:50+00:00"
+ "time": "2025-09-25T15:37:27+00:00"
},
{
"name": "symfony/var-exporter",
- "version": "v6.4.22",
+ "version": "v6.4.26",
"source": {
"type": "git",
"url": "https://github.com/symfony/var-exporter.git",
- "reference": "f28cf841f5654955c9f88ceaf4b9dc29571988a9"
+ "reference": "466fcac5fa2e871f83d31173f80e9c2684743bfc"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/var-exporter/zipball/f28cf841f5654955c9f88ceaf4b9dc29571988a9",
- "reference": "f28cf841f5654955c9f88ceaf4b9dc29571988a9",
+ "url": "https://api.github.com/repos/symfony/var-exporter/zipball/466fcac5fa2e871f83d31173f80e9c2684743bfc",
+ "reference": "466fcac5fa2e871f83d31173f80e9c2684743bfc",
"shasum": ""
},
"require": {
@@ -3552,7 +3686,7 @@
"serialize"
],
"support": {
- "source": "https://github.com/symfony/var-exporter/tree/v6.4.22"
+ "source": "https://github.com/symfony/var-exporter/tree/v6.4.26"
},
"funding": [
{
@@ -3563,25 +3697,29 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2025-05-14T13:00:13+00:00"
+ "time": "2025-09-11T09:57:09+00:00"
},
{
"name": "symfony/yaml",
- "version": "v6.4.21",
+ "version": "v6.4.26",
"source": {
"type": "git",
"url": "https://github.com/symfony/yaml.git",
- "reference": "f01987f45676778b474468aa266fe2eda1f2bc7e"
+ "reference": "0fc8b966fd0dcaab544ae59bfc3a433f048c17b0"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/yaml/zipball/f01987f45676778b474468aa266fe2eda1f2bc7e",
- "reference": "f01987f45676778b474468aa266fe2eda1f2bc7e",
+ "url": "https://api.github.com/repos/symfony/yaml/zipball/0fc8b966fd0dcaab544ae59bfc3a433f048c17b0",
+ "reference": "0fc8b966fd0dcaab544ae59bfc3a433f048c17b0",
"shasum": ""
},
"require": {
@@ -3624,7 +3762,7 @@
"description": "Loads and dumps YAML files",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/yaml/tree/v6.4.21"
+ "source": "https://github.com/symfony/yaml/tree/v6.4.26"
},
"funding": [
{
@@ -3635,12 +3773,16 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2025-04-04T09:48:44+00:00"
+ "time": "2025-09-26T15:07:38+00:00"
},
{
"name": "twig/intl-extra",
@@ -3847,28 +3989,28 @@
"packages-dev": [
{
"name": "dealerdirect/phpcodesniffer-composer-installer",
- "version": "v1.0.0",
+ "version": "v1.1.2",
"source": {
"type": "git",
"url": "https://github.com/PHPCSStandards/composer-installer.git",
- "reference": "4be43904336affa5c2f70744a348312336afd0da"
+ "reference": "e9cf5e4bbf7eeaf9ef5db34938942602838fc2b1"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/PHPCSStandards/composer-installer/zipball/4be43904336affa5c2f70744a348312336afd0da",
- "reference": "4be43904336affa5c2f70744a348312336afd0da",
+ "url": "https://api.github.com/repos/PHPCSStandards/composer-installer/zipball/e9cf5e4bbf7eeaf9ef5db34938942602838fc2b1",
+ "reference": "e9cf5e4bbf7eeaf9ef5db34938942602838fc2b1",
"shasum": ""
},
"require": {
- "composer-plugin-api": "^1.0 || ^2.0",
+ "composer-plugin-api": "^2.2",
"php": ">=5.4",
"squizlabs/php_codesniffer": "^2.0 || ^3.1.0 || ^4.0"
},
"require-dev": {
- "composer/composer": "*",
+ "composer/composer": "^2.2",
"ext-json": "*",
"ext-zip": "*",
- "php-parallel-lint/php-parallel-lint": "^1.3.1",
+ "php-parallel-lint/php-parallel-lint": "^1.4.0",
"phpcompatibility/php-compatibility": "^9.0",
"yoast/phpunit-polyfills": "^1.0"
},
@@ -3888,9 +4030,9 @@
"authors": [
{
"name": "Franck Nijhof",
- "email": "franck.nijhof@dealerdirect.com",
- "homepage": "http://www.frenck.nl",
- "role": "Developer / IT Manager"
+ "email": "opensource@frenck.dev",
+ "homepage": "https://frenck.dev",
+ "role": "Open source developer"
},
{
"name": "Contributors",
@@ -3898,7 +4040,6 @@
}
],
"description": "PHP_CodeSniffer Standards Composer Installer Plugin",
- "homepage": "http://www.dealerdirect.com",
"keywords": [
"PHPCodeSniffer",
"PHP_CodeSniffer",
@@ -3919,9 +4060,28 @@
],
"support": {
"issues": "https://github.com/PHPCSStandards/composer-installer/issues",
+ "security": "https://github.com/PHPCSStandards/composer-installer/security/policy",
"source": "https://github.com/PHPCSStandards/composer-installer"
},
- "time": "2023-01-05T11:28:13+00:00"
+ "funding": [
+ {
+ "url": "https://github.com/PHPCSStandards",
+ "type": "github"
+ },
+ {
+ "url": "https://github.com/jrfnl",
+ "type": "github"
+ },
+ {
+ "url": "https://opencollective.com/php_codesniffer",
+ "type": "open_collective"
+ },
+ {
+ "url": "https://thanks.dev/u/gh/phpcsstandards",
+ "type": "thanks_dev"
+ }
+ ],
+ "time": "2025-07-17T20:45:56+00:00"
},
{
"name": "gettext/php-scanner",
@@ -4036,16 +4196,16 @@
},
{
"name": "myclabs/deep-copy",
- "version": "1.13.1",
+ "version": "1.13.4",
"source": {
"type": "git",
"url": "https://github.com/myclabs/DeepCopy.git",
- "reference": "1720ddd719e16cf0db4eb1c6eca108031636d46c"
+ "reference": "07d290f0c47959fd5eed98c95ee5602db07e0b6a"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/myclabs/DeepCopy/zipball/1720ddd719e16cf0db4eb1c6eca108031636d46c",
- "reference": "1720ddd719e16cf0db4eb1c6eca108031636d46c",
+ "url": "https://api.github.com/repos/myclabs/DeepCopy/zipball/07d290f0c47959fd5eed98c95ee5602db07e0b6a",
+ "reference": "07d290f0c47959fd5eed98c95ee5602db07e0b6a",
"shasum": ""
},
"require": {
@@ -4084,7 +4244,7 @@
],
"support": {
"issues": "https://github.com/myclabs/DeepCopy/issues",
- "source": "https://github.com/myclabs/DeepCopy/tree/1.13.1"
+ "source": "https://github.com/myclabs/DeepCopy/tree/1.13.4"
},
"funding": [
{
@@ -4092,7 +4252,7 @@
"type": "tidelift"
}
],
- "time": "2025-04-29T12:36:36+00:00"
+ "time": "2025-08-01T08:46:24+00:00"
},
{
"name": "nikic/php-parser",
@@ -4318,16 +4478,16 @@
},
{
"name": "phpstan/phpdoc-parser",
- "version": "2.1.0",
+ "version": "2.3.0",
"source": {
"type": "git",
"url": "https://github.com/phpstan/phpdoc-parser.git",
- "reference": "9b30d6fd026b2c132b3985ce6b23bec09ab3aa68"
+ "reference": "1e0cd5370df5dd2e556a36b9c62f62e555870495"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/phpstan/phpdoc-parser/zipball/9b30d6fd026b2c132b3985ce6b23bec09ab3aa68",
- "reference": "9b30d6fd026b2c132b3985ce6b23bec09ab3aa68",
+ "url": "https://api.github.com/repos/phpstan/phpdoc-parser/zipball/1e0cd5370df5dd2e556a36b9c62f62e555870495",
+ "reference": "1e0cd5370df5dd2e556a36b9c62f62e555870495",
"shasum": ""
},
"require": {
@@ -4359,22 +4519,17 @@
"description": "PHPDoc parser with support for nullable, intersection and generic types",
"support": {
"issues": "https://github.com/phpstan/phpdoc-parser/issues",
- "source": "https://github.com/phpstan/phpdoc-parser/tree/2.1.0"
+ "source": "https://github.com/phpstan/phpdoc-parser/tree/2.3.0"
},
- "time": "2025-02-19T13:28:12+00:00"
+ "time": "2025-08-30T15:50:23+00:00"
},
{
"name": "phpstan/phpstan",
- "version": "1.12.27",
- "source": {
- "type": "git",
- "url": "https://github.com/phpstan/phpstan.git",
- "reference": "3a6e423c076ab39dfedc307e2ac627ef579db162"
- },
+ "version": "1.12.32",
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/phpstan/phpstan/zipball/3a6e423c076ab39dfedc307e2ac627ef579db162",
- "reference": "3a6e423c076ab39dfedc307e2ac627ef579db162",
+ "url": "https://api.github.com/repos/phpstan/phpstan/zipball/2770dcdf5078d0b0d53f94317e06affe88419aa8",
+ "reference": "2770dcdf5078d0b0d53f94317e06affe88419aa8",
"shasum": ""
},
"require": {
@@ -4419,7 +4574,7 @@
"type": "github"
}
],
- "time": "2025-05-21T20:51:45+00:00"
+ "time": "2025-09-30T10:16:31+00:00"
},
{
"name": "phpstan/phpstan-mockery",
@@ -4794,16 +4949,16 @@
},
{
"name": "phpunit/phpunit",
- "version": "10.5.46",
+ "version": "10.5.58",
"source": {
"type": "git",
"url": "https://github.com/sebastianbergmann/phpunit.git",
- "reference": "8080be387a5be380dda48c6f41cee4a13aadab3d"
+ "reference": "e24fb46da450d8e6a5788670513c1af1424f16ca"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/sebastianbergmann/phpunit/zipball/8080be387a5be380dda48c6f41cee4a13aadab3d",
- "reference": "8080be387a5be380dda48c6f41cee4a13aadab3d",
+ "url": "https://api.github.com/repos/sebastianbergmann/phpunit/zipball/e24fb46da450d8e6a5788670513c1af1424f16ca",
+ "reference": "e24fb46da450d8e6a5788670513c1af1424f16ca",
"shasum": ""
},
"require": {
@@ -4813,7 +4968,7 @@
"ext-mbstring": "*",
"ext-xml": "*",
"ext-xmlwriter": "*",
- "myclabs/deep-copy": "^1.13.1",
+ "myclabs/deep-copy": "^1.13.4",
"phar-io/manifest": "^2.0.4",
"phar-io/version": "^3.2.1",
"php": ">=8.1",
@@ -4824,13 +4979,13 @@
"phpunit/php-timer": "^6.0.0",
"sebastian/cli-parser": "^2.0.1",
"sebastian/code-unit": "^2.0.0",
- "sebastian/comparator": "^5.0.3",
+ "sebastian/comparator": "^5.0.4",
"sebastian/diff": "^5.1.1",
"sebastian/environment": "^6.1.0",
- "sebastian/exporter": "^5.1.2",
+ "sebastian/exporter": "^5.1.4",
"sebastian/global-state": "^6.0.2",
"sebastian/object-enumerator": "^5.0.0",
- "sebastian/recursion-context": "^5.0.0",
+ "sebastian/recursion-context": "^5.0.1",
"sebastian/type": "^4.0.0",
"sebastian/version": "^4.0.1"
},
@@ -4875,7 +5030,7 @@
"support": {
"issues": "https://github.com/sebastianbergmann/phpunit/issues",
"security": "https://github.com/sebastianbergmann/phpunit/security/policy",
- "source": "https://github.com/sebastianbergmann/phpunit/tree/10.5.46"
+ "source": "https://github.com/sebastianbergmann/phpunit/tree/10.5.58"
},
"funding": [
{
@@ -4899,7 +5054,7 @@
"type": "tidelift"
}
],
- "time": "2025-05-02T06:46:24+00:00"
+ "time": "2025-09-28T12:04:46+00:00"
},
{
"name": "predis/predis",
@@ -5133,16 +5288,16 @@
},
{
"name": "sebastian/comparator",
- "version": "5.0.3",
+ "version": "5.0.4",
"source": {
"type": "git",
"url": "https://github.com/sebastianbergmann/comparator.git",
- "reference": "a18251eb0b7a2dcd2f7aa3d6078b18545ef0558e"
+ "reference": "e8e53097718d2b53cfb2aa859b06a41abf58c62e"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/sebastianbergmann/comparator/zipball/a18251eb0b7a2dcd2f7aa3d6078b18545ef0558e",
- "reference": "a18251eb0b7a2dcd2f7aa3d6078b18545ef0558e",
+ "url": "https://api.github.com/repos/sebastianbergmann/comparator/zipball/e8e53097718d2b53cfb2aa859b06a41abf58c62e",
+ "reference": "e8e53097718d2b53cfb2aa859b06a41abf58c62e",
"shasum": ""
},
"require": {
@@ -5198,15 +5353,27 @@
"support": {
"issues": "https://github.com/sebastianbergmann/comparator/issues",
"security": "https://github.com/sebastianbergmann/comparator/security/policy",
- "source": "https://github.com/sebastianbergmann/comparator/tree/5.0.3"
+ "source": "https://github.com/sebastianbergmann/comparator/tree/5.0.4"
},
"funding": [
{
"url": "https://github.com/sebastianbergmann",
"type": "github"
+ },
+ {
+ "url": "https://liberapay.com/sebastianbergmann",
+ "type": "liberapay"
+ },
+ {
+ "url": "https://thanks.dev/u/gh/sebastianbergmann",
+ "type": "thanks_dev"
+ },
+ {
+ "url": "https://tidelift.com/funding/github/packagist/sebastian/comparator",
+ "type": "tidelift"
}
],
- "time": "2024-10-18T14:56:07+00:00"
+ "time": "2025-09-07T05:25:07+00:00"
},
{
"name": "sebastian/complexity",
@@ -5399,16 +5566,16 @@
},
{
"name": "sebastian/exporter",
- "version": "5.1.2",
+ "version": "5.1.4",
"source": {
"type": "git",
"url": "https://github.com/sebastianbergmann/exporter.git",
- "reference": "955288482d97c19a372d3f31006ab3f37da47adf"
+ "reference": "0735b90f4da94969541dac1da743446e276defa6"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/sebastianbergmann/exporter/zipball/955288482d97c19a372d3f31006ab3f37da47adf",
- "reference": "955288482d97c19a372d3f31006ab3f37da47adf",
+ "url": "https://api.github.com/repos/sebastianbergmann/exporter/zipball/0735b90f4da94969541dac1da743446e276defa6",
+ "reference": "0735b90f4da94969541dac1da743446e276defa6",
"shasum": ""
},
"require": {
@@ -5417,7 +5584,7 @@
"sebastian/recursion-context": "^5.0"
},
"require-dev": {
- "phpunit/phpunit": "^10.0"
+ "phpunit/phpunit": "^10.5"
},
"type": "library",
"extra": {
@@ -5465,15 +5632,27 @@
"support": {
"issues": "https://github.com/sebastianbergmann/exporter/issues",
"security": "https://github.com/sebastianbergmann/exporter/security/policy",
- "source": "https://github.com/sebastianbergmann/exporter/tree/5.1.2"
+ "source": "https://github.com/sebastianbergmann/exporter/tree/5.1.4"
},
"funding": [
{
"url": "https://github.com/sebastianbergmann",
"type": "github"
+ },
+ {
+ "url": "https://liberapay.com/sebastianbergmann",
+ "type": "liberapay"
+ },
+ {
+ "url": "https://thanks.dev/u/gh/sebastianbergmann",
+ "type": "thanks_dev"
+ },
+ {
+ "url": "https://tidelift.com/funding/github/packagist/sebastian/exporter",
+ "type": "tidelift"
}
],
- "time": "2024-03-02T07:17:12+00:00"
+ "time": "2025-09-24T06:09:11+00:00"
},
{
"name": "sebastian/global-state",
@@ -5709,23 +5888,23 @@
},
{
"name": "sebastian/recursion-context",
- "version": "5.0.0",
+ "version": "5.0.1",
"source": {
"type": "git",
"url": "https://github.com/sebastianbergmann/recursion-context.git",
- "reference": "05909fb5bc7df4c52992396d0116aed689f93712"
+ "reference": "47e34210757a2f37a97dcd207d032e1b01e64c7a"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/sebastianbergmann/recursion-context/zipball/05909fb5bc7df4c52992396d0116aed689f93712",
- "reference": "05909fb5bc7df4c52992396d0116aed689f93712",
+ "url": "https://api.github.com/repos/sebastianbergmann/recursion-context/zipball/47e34210757a2f37a97dcd207d032e1b01e64c7a",
+ "reference": "47e34210757a2f37a97dcd207d032e1b01e64c7a",
"shasum": ""
},
"require": {
"php": ">=8.1"
},
"require-dev": {
- "phpunit/phpunit": "^10.0"
+ "phpunit/phpunit": "^10.5"
},
"type": "library",
"extra": {
@@ -5760,15 +5939,28 @@
"homepage": "https://github.com/sebastianbergmann/recursion-context",
"support": {
"issues": "https://github.com/sebastianbergmann/recursion-context/issues",
- "source": "https://github.com/sebastianbergmann/recursion-context/tree/5.0.0"
+ "security": "https://github.com/sebastianbergmann/recursion-context/security/policy",
+ "source": "https://github.com/sebastianbergmann/recursion-context/tree/5.0.1"
},
"funding": [
{
"url": "https://github.com/sebastianbergmann",
"type": "github"
+ },
+ {
+ "url": "https://liberapay.com/sebastianbergmann",
+ "type": "liberapay"
+ },
+ {
+ "url": "https://thanks.dev/u/gh/sebastianbergmann",
+ "type": "thanks_dev"
+ },
+ {
+ "url": "https://tidelift.com/funding/github/packagist/sebastian/recursion-context",
+ "type": "tidelift"
}
],
- "time": "2023-02-03T07:05:40+00:00"
+ "time": "2025-08-10T07:50:56+00:00"
},
{
"name": "sebastian/type",
@@ -5881,16 +6073,16 @@
},
{
"name": "simplesamlphp/saml2-legacy",
- "version": "v4.18.1",
+ "version": "v4.19.0",
"source": {
"type": "git",
"url": "https://github.com/simplesamlphp/saml2-legacy.git",
- "reference": "9bbf43a5ace9c8e5107dad3a613b014b456ecd56"
+ "reference": "96eb144356702d7d913078fb2e4364e42458fc31"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/simplesamlphp/saml2-legacy/zipball/9bbf43a5ace9c8e5107dad3a613b014b456ecd56",
- "reference": "9bbf43a5ace9c8e5107dad3a613b014b456ecd56",
+ "url": "https://api.github.com/repos/simplesamlphp/saml2-legacy/zipball/96eb144356702d7d913078fb2e4364e42458fc31",
+ "reference": "96eb144356702d7d913078fb2e4364e42458fc31",
"shasum": ""
},
"require": {
@@ -5935,9 +6127,9 @@
],
"description": "SAML2 PHP library from SimpleSAMLphp",
"support": {
- "source": "https://github.com/simplesamlphp/saml2-legacy/tree/v4.18.1"
+ "source": "https://github.com/simplesamlphp/saml2-legacy/tree/v4.19.0"
},
- "time": "2025-03-16T11:50:02+00:00"
+ "time": "2025-09-05T23:39:13+00:00"
},
{
"name": "simplesamlphp/simplesamlphp-module-adfs",
@@ -6001,16 +6193,16 @@
},
{
"name": "simplesamlphp/simplesamlphp-test-framework",
- "version": "v1.9.2",
+ "version": "v1.9.3",
"source": {
"type": "git",
"url": "https://github.com/simplesamlphp/simplesamlphp-test-framework.git",
- "reference": "b8506d7b59c658ff4bb9bdd301bf24d1635019d1"
+ "reference": "8dd14bb338573710165e6c237ec36378fa18eadb"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/simplesamlphp/simplesamlphp-test-framework/zipball/b8506d7b59c658ff4bb9bdd301bf24d1635019d1",
- "reference": "b8506d7b59c658ff4bb9bdd301bf24d1635019d1",
+ "url": "https://api.github.com/repos/simplesamlphp/simplesamlphp-test-framework/zipball/8dd14bb338573710165e6c237ec36378fa18eadb",
+ "reference": "8dd14bb338573710165e6c237ec36378fa18eadb",
"shasum": ""
},
"require": {
@@ -6025,7 +6217,7 @@
"symfony/phpunit-bridge": "^6.4 || ^7.0"
},
"require-dev": {
- "simplesamlphp/simplesamlphp": "^2.2"
+ "simplesamlphp/simplesamlphp": "^2.4"
},
"type": "project",
"autoload": {
@@ -6051,36 +6243,36 @@
"issues": "https://github.com/simplesamlphp/simplesamlphp-test-framework/issues",
"source": "https://github.com/simplesamlphp/simplesamlphp-test-framework"
},
- "time": "2025-04-07T20:08:55+00:00"
+ "time": "2025-07-14T17:03:27+00:00"
},
{
"name": "slevomat/coding-standard",
- "version": "8.19.1",
+ "version": "8.24.0",
"source": {
"type": "git",
"url": "https://github.com/slevomat/coding-standard.git",
- "reference": "458d665acd49009efebd7e0cb385d71ae9ac3220"
+ "reference": "08e7989c0351f3f38b82172838195c35d9819efa"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/slevomat/coding-standard/zipball/458d665acd49009efebd7e0cb385d71ae9ac3220",
- "reference": "458d665acd49009efebd7e0cb385d71ae9ac3220",
+ "url": "https://api.github.com/repos/slevomat/coding-standard/zipball/08e7989c0351f3f38b82172838195c35d9819efa",
+ "reference": "08e7989c0351f3f38b82172838195c35d9819efa",
"shasum": ""
},
"require": {
- "dealerdirect/phpcodesniffer-composer-installer": "^0.6.2 || ^0.7 || ^1.0",
+ "dealerdirect/phpcodesniffer-composer-installer": "^0.6.2 || ^0.7 || ^1.1.2",
"php": "^7.4 || ^8.0",
- "phpstan/phpdoc-parser": "^2.1.0",
- "squizlabs/php_codesniffer": "^3.13.0"
+ "phpstan/phpdoc-parser": "^2.3.0",
+ "squizlabs/php_codesniffer": "^4.0.0"
},
"require-dev": {
- "phing/phing": "3.0.1",
+ "phing/phing": "3.0.1|3.1.0",
"php-parallel-lint/php-parallel-lint": "1.4.0",
- "phpstan/phpstan": "2.1.17",
+ "phpstan/phpstan": "2.1.29",
"phpstan/phpstan-deprecation-rules": "2.0.3",
- "phpstan/phpstan-phpunit": "2.0.6",
- "phpstan/phpstan-strict-rules": "2.0.4",
- "phpunit/phpunit": "9.6.8|10.5.45|11.4.4|11.5.21|12.1.3"
+ "phpstan/phpstan-phpunit": "2.0.7",
+ "phpstan/phpstan-strict-rules": "2.0.6",
+ "phpunit/phpunit": "9.6.8|10.5.48|11.4.4|11.5.36|12.3.14"
},
"type": "phpcodesniffer-standard",
"extra": {
@@ -6104,7 +6296,7 @@
],
"support": {
"issues": "https://github.com/slevomat/coding-standard/issues",
- "source": "https://github.com/slevomat/coding-standard/tree/8.19.1"
+ "source": "https://github.com/slevomat/coding-standard/tree/8.24.0"
},
"funding": [
{
@@ -6116,41 +6308,36 @@
"type": "tidelift"
}
],
- "time": "2025-06-09T17:53:57+00:00"
+ "time": "2025-09-25T21:37:40+00:00"
},
{
"name": "squizlabs/php_codesniffer",
- "version": "3.13.1",
+ "version": "4.0.0",
"source": {
"type": "git",
"url": "https://github.com/PHPCSStandards/PHP_CodeSniffer.git",
- "reference": "1b71b4dd7e7ef651ac749cea67e513c0c832f4bd"
+ "reference": "06113cfdaf117fc2165f9cd040bd0f17fcd5242d"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/PHPCSStandards/PHP_CodeSniffer/zipball/1b71b4dd7e7ef651ac749cea67e513c0c832f4bd",
- "reference": "1b71b4dd7e7ef651ac749cea67e513c0c832f4bd",
+ "url": "https://api.github.com/repos/PHPCSStandards/PHP_CodeSniffer/zipball/06113cfdaf117fc2165f9cd040bd0f17fcd5242d",
+ "reference": "06113cfdaf117fc2165f9cd040bd0f17fcd5242d",
"shasum": ""
},
"require": {
"ext-simplexml": "*",
"ext-tokenizer": "*",
"ext-xmlwriter": "*",
- "php": ">=5.4.0"
+ "php": ">=7.2.0"
},
"require-dev": {
- "phpunit/phpunit": "^4.0 || ^5.0 || ^6.0 || ^7.0 || ^8.0 || ^9.3.4"
+ "phpunit/phpunit": "^8.4.0 || ^9.3.4 || ^10.5.32 || 11.3.3 - 11.5.28 || ^11.5.31"
},
"bin": [
"bin/phpcbf",
"bin/phpcs"
],
"type": "library",
- "extra": {
- "branch-alias": {
- "dev-master": "3.x-dev"
- }
- },
"notification-url": "https://packagist.org/downloads/",
"license": [
"BSD-3-Clause"
@@ -6169,7 +6356,7 @@
"homepage": "https://github.com/PHPCSStandards/PHP_CodeSniffer/graphs/contributors"
}
],
- "description": "PHP_CodeSniffer tokenizes PHP, JavaScript and CSS files and detects violations of a defined set of coding standards.",
+ "description": "PHP_CodeSniffer tokenizes PHP files and detects violations of a defined set of coding standards.",
"homepage": "https://github.com/PHPCSStandards/PHP_CodeSniffer",
"keywords": [
"phpcs",
@@ -6200,20 +6387,20 @@
"type": "thanks_dev"
}
],
- "time": "2025-06-12T15:04:34+00:00"
+ "time": "2025-09-15T11:28:58+00:00"
},
{
"name": "symfony/phpunit-bridge",
- "version": "v7.3.0",
+ "version": "v7.3.4",
"source": {
"type": "git",
"url": "https://github.com/symfony/phpunit-bridge.git",
- "reference": "2eabda563921f21cbce1d1e3247b3c36568905e6"
+ "reference": "ed77a629c13979e051b7000a317966474d566398"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/phpunit-bridge/zipball/2eabda563921f21cbce1d1e3247b3c36568905e6",
- "reference": "2eabda563921f21cbce1d1e3247b3c36568905e6",
+ "url": "https://api.github.com/repos/symfony/phpunit-bridge/zipball/ed77a629c13979e051b7000a317966474d566398",
+ "reference": "ed77a629c13979e051b7000a317966474d566398",
"shasum": ""
},
"require": {
@@ -6265,8 +6452,11 @@
],
"description": "Provides utilities for PHPUnit, especially user deprecation notices management",
"homepage": "https://symfony.com",
+ "keywords": [
+ "testing"
+ ],
"support": {
- "source": "https://github.com/symfony/phpunit-bridge/tree/v7.3.0"
+ "source": "https://github.com/symfony/phpunit-bridge/tree/v7.3.4"
},
"funding": [
{
@@ -6277,25 +6467,29 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2025-05-23T07:26:30+00:00"
+ "time": "2025-09-12T12:18:52+00:00"
},
{
"name": "symfony/translation",
- "version": "v6.4.22",
+ "version": "v6.4.26",
"source": {
"type": "git",
"url": "https://github.com/symfony/translation.git",
- "reference": "7e3b3b7146c6fab36ddff304a8041174bf6e17ad"
+ "reference": "c8559fe25c7ee7aa9d28f228903a46db008156a4"
},
"dist": {
"type": "zip",
- "url": "https://api.github.com/repos/symfony/translation/zipball/7e3b3b7146c6fab36ddff304a8041174bf6e17ad",
- "reference": "7e3b3b7146c6fab36ddff304a8041174bf6e17ad",
+ "url": "https://api.github.com/repos/symfony/translation/zipball/c8559fe25c7ee7aa9d28f228903a46db008156a4",
+ "reference": "c8559fe25c7ee7aa9d28f228903a46db008156a4",
"shasum": ""
},
"require": {
@@ -6361,7 +6555,7 @@
"description": "Provides tools to internationalize your application",
"homepage": "https://symfony.com",
"support": {
- "source": "https://github.com/symfony/translation/tree/v6.4.22"
+ "source": "https://github.com/symfony/translation/tree/v6.4.26"
},
"funding": [
{
@@ -6372,12 +6566,16 @@
"url": "https://github.com/fabpot",
"type": "github"
},
+ {
+ "url": "https://github.com/nicolas-grekas",
+ "type": "github"
+ },
{
"url": "https://tidelift.com/funding/github/packagist/symfony/symfony",
"type": "tidelift"
}
],
- "time": "2025-05-29T07:06:44+00:00"
+ "time": "2025-09-05T18:17:25+00:00"
},
{
"name": "theseer/tokenizer",
diff --git a/docs/simplesamlphp-changelog.md b/docs/simplesamlphp-changelog.md
index 413f76fc69..96eb4d77ec 100644
--- a/docs/simplesamlphp-changelog.md
+++ b/docs/simplesamlphp-changelog.md
@@ -5,10 +5,24 @@
This document lists the changes between versions of SimpleSAMLphp.
See the [upgrade notes](https://simplesamlphp.org/docs/stable/simplesamlphp-upgrade-notes.html) for specific information about upgrading.
-## Version 2.3.9
+## Version 2.3.10
Released TBD
+## Version 2.3.9
+
+Released 2025-10-05
+
+* Fix auth state AuthnInstant (#2478)
+* Allow "Secure" cookie attribute via HTTP on localhost (#2483)
+* Fix override over errorURL
+* Fix FontAwesome icon names (#2509)
+* Prevent emulation of SQL prepare-statements
+* Remove double directory separator; \SimpleSAML\Configuration::getBasedir always ends with one
+
+`authorize`
+
+* Remove reauthentication-button when reauthentication is disabled (simplesamlphp/simplesamlphp-module-authorize#24) (v1.6.2)
## Version 2.3.8
@@ -158,6 +172,48 @@ Released 2024-08-20
* Add username_regex option - run regular expression over username before querying the
database (simplesamlphp/simplesamlphp-module-sqlauth#11) (v1.3.0)
+## Version 2.2.6
+
+Released 2025-08-20
+
+* Fix auth state AuthnInstant (#2478)
+
+`cron`
+
+* Fixed a security-issue where cron-jobs could be executed using the default key,
+ even if a different one was set (#2453)
+
+`metarefresh`
+
+* Fixed parsing of large metadata files (v1.2.4)
+
+## Version 2.2.5
+
+Released 2025-03-11
+
+* Fixed PHP 8.4 deprecation notices
+* Fixed infinite recursion (#2367)
+* Fixed "Undefined array key" warning in RequestedAuthnContextSelector if no RAC is present in the request
+* Bumped vulnerable saml2-library to v4.17.0
+
+## Version 2.2.4
+
+Released 2024-12-02
+
+`Security`
+
+* A security bug was patched in the `saml2-library` that allowed for XXE during the parsing
+ of SAML2-messages (CVE-2024-52596)
+
+`Other fixes`
+
+* Run ob_end_clean() on configuration file parsing error (#2219)
+* Fix typo that caused the metadata file-upload to be hidden (#2271)
+
+`admin`
+
+* Fix metadata-viewer to output a valid PHP array
+
## Version 2.2.3
Released 2024-08-20
diff --git a/docs/simplesamlphp-customauth.md b/docs/simplesamlphp-customauth.md
index 72b336ebb1..a6de7a20de 100644
--- a/docs/simplesamlphp-customauth.md
+++ b/docs/simplesamlphp-customauth.md
@@ -352,6 +352,7 @@ class MyAuth extends \SimpleSAML\Module\core\Auth\UserPassBase
/* Connect to the database. */
$db = new PDO($this->dsn, $this->username, $this->password, $this->options);
$db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
+ $db->setAttribute(PDO::ATTR_EMULATE_PREPARES, false);
/* Ensure that we are operating with UTF-8 encoding.
* This command is for MySQL. Other databases may need different commands.
diff --git a/docs/simplesamlphp-reference-sp-remote.md b/docs/simplesamlphp-reference-sp-remote.md
index f032d20c30..d67f225c49 100644
--- a/docs/simplesamlphp-reference-sp-remote.md
+++ b/docs/simplesamlphp-reference-sp-remote.md
@@ -166,10 +166,9 @@ The following options can be set:
: The three most commonly used values are:
-:
- 1. `urn:oasis:names:tc:SAML:2.0:nameid-format:transient`
- 2. `urn:oasis:names:tc:SAML:2.0:nameid-format:persistent`
- 3. `urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress`
+* `urn:oasis:names:tc:SAML:2.0:nameid-format:transient`
+* `urn:oasis:names:tc:SAML:2.0:nameid-format:persistent`
+* `urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress`
: The `transient` format will generate a new unique ID every time
the SP logs in.
diff --git a/extra/simplesamlphp.spec b/extra/simplesamlphp.spec
index 69e010555b..070bf637ef 100644
--- a/extra/simplesamlphp.spec
+++ b/extra/simplesamlphp.spec
@@ -1,6 +1,6 @@
%define name simplesamlphp
%define summary SAML IDP/SP written in PHP
-%define version 2.3.8
+%define version 2.3.9
%define release 1
%define license LGPL 2.1
%define group Networking/WWW
diff --git a/modules/admin/templates/federation.twig b/modules/admin/templates/federation.twig
index 017a5f6b0f..dae9211d04 100644
--- a/modules/admin/templates/federation.twig
+++ b/modules/admin/templates/federation.twig
@@ -56,7 +56,7 @@
-
+
{{ set.url }}
diff --git a/modules/core/src/Storage/SQLPermanentStorage.php b/modules/core/src/Storage/SQLPermanentStorage.php
index 61095c9baf..552b91de34 100644
--- a/modules/core/src/Storage/SQLPermanentStorage.php
+++ b/modules/core/src/Storage/SQLPermanentStorage.php
@@ -53,6 +53,8 @@ public function __construct(string $name, ?Configuration $config = null)
$this->db = new PDO($dbfile);
if ($this->db) {
$this->db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT);
+ $this->db->setAttribute(PDO::ATTR_EMULATE_PREPARES, false);
+
$q = @$this->db->query('SELECT key1 FROM data LIMIT 1');
if ($q === false) {
$this->db->exec('
diff --git a/modules/core/templates/logout-iframe.twig b/modules/core/templates/logout-iframe.twig
index 1cd8b2d54c..5c96865c2f 100644
--- a/modules/core/templates/logout-iframe.twig
+++ b/modules/core/templates/logout-iframe.twig
@@ -37,11 +37,11 @@
{%- for key, sp in remaining_services %}
{%- set timeout = 5 %}
{%- set name = sp['metadata']|entityDisplayName %}
- {%- set icon = 'circle-o-notch' %}
+ {%- set icon = 'circle-notch' %}
{%- if sp['status'] == 'completed' %}
- {%- set icon = 'check-circle' %}
+ {%- set icon = 'circle-check' %}
{%- elseif sp['status'] == 'failed' %}
- {%- set icon = 'exclamation-circle' %}
+ {%- set icon = 'circle-exclamation' %}
{%- set failed = true %}
{%- elseif (sp['status'] == 'onhold' or sp['status'] == 'inprogress') %}
{%- set remaining = remaining + 1 %}
diff --git a/modules/saml/docs/sp.md b/modules/saml/docs/sp.md
index de53d333ec..3312455cbe 100644
--- a/modules/saml/docs/sp.md
+++ b/modules/saml/docs/sp.md
@@ -153,7 +153,7 @@ The following attributes are available:
`authproc`
: Processing filters that should be run after SP authentication.
- See the [authentication processing filter manual](simplesamlphp-authproc).
+ See the [authentication processing filter manual](../simplesamlphp-authproc).
`certData`
: Base64 encoded certificate data. Can be used instead of the `certificate` option.
diff --git a/modules/saml/src/IdP/SAML2.php b/modules/saml/src/IdP/SAML2.php
index 1695d89aaf..42ea3f369c 100644
--- a/modules/saml/src/IdP/SAML2.php
+++ b/modules/saml/src/IdP/SAML2.php
@@ -962,6 +962,11 @@ public static function getHostedMetadata(string $entityid, ?MetaDataStorageHandl
$metadata['RegistrationInfo'] = $config->getArray('RegistrationInfo');
}
+ // Override errorURL if set
+ if ($config->hasValue('errorURL')) {
+ $metadata['errorURL'] = $config->getString('errorURL');
+ }
+
// configure signature options
if ($config->hasValue('validate.authnrequest')) {
$metadata['sign.authnrequest'] = $config->getBoolean('validate.authnrequest');
diff --git a/phpcs.xml b/phpcs.xml
index ec365ed6ac..9b5cdd9011 100644
--- a/phpcs.xml
+++ b/phpcs.xml
@@ -31,6 +31,7 @@
tests/src/SimpleSAML/Metadata/MetaDataStorageSourceTest.php
tests/src/SimpleSAML/Metadata/SAMLParserTest.php
+ tests/src/SimpleSAML/Utils/HTTPTest.php
tests/modules/saml/src/Controller/ServiceProviderTest.php
diff --git a/psalm.xml b/psalm.xml
index de26cb641f..1fa1b3660c 100644
--- a/psalm.xml
+++ b/psalm.xml
@@ -21,7 +21,7 @@
-
+
@@ -78,7 +78,6 @@
-
diff --git a/src/SimpleSAML/Auth/State.php b/src/SimpleSAML/Auth/State.php
index 814b4394b6..55399563c3 100644
--- a/src/SimpleSAML/Auth/State.php
+++ b/src/SimpleSAML/Auth/State.php
@@ -126,7 +126,7 @@ public static function getPersistentAuthData(array $state): array
'Attributes',
'Expire',
'LogoutState',
- 'AuthInstant',
+ 'AuthnInstant',
'RememberMe',
'saml:sp:NameID',
];
diff --git a/src/SimpleSAML/Configuration.php b/src/SimpleSAML/Configuration.php
index 0158c319e8..2cbc136fd7 100644
--- a/src/SimpleSAML/Configuration.php
+++ b/src/SimpleSAML/Configuration.php
@@ -41,7 +41,7 @@ class Configuration implements Utils\ClearableState
/**
* The release version of this package
*/
- public const VERSION = '2.3.8';
+ public const VERSION = '2.3.9';
/**
* A default value which means that the given option is required.
diff --git a/src/SimpleSAML/Database.php b/src/SimpleSAML/Database.php
index 588b1b4eb9..e6e46a2fc1 100644
--- a/src/SimpleSAML/Database.php
+++ b/src/SimpleSAML/Database.php
@@ -169,6 +169,7 @@ private function connect(string $dsn, ?string $username = null, ?string $passwor
try {
$db = new PDO($dsn, $username, $password, $options);
$db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
+ $db->setAttribute(PDO::ATTR_EMULATE_PREPARES, false);
return $db;
} catch (PDOException $e) {
diff --git a/src/SimpleSAML/Kernel.php b/src/SimpleSAML/Kernel.php
index ab30f77cfb..bb001642b3 100644
--- a/src/SimpleSAML/Kernel.php
+++ b/src/SimpleSAML/Kernel.php
@@ -66,7 +66,7 @@ public function getCacheDir(): string
return $cachePath;
}
- return $configuration->getBaseDir() . DIRECTORY_SEPARATOR . $cachePath;
+ return $configuration->getBaseDir() . $cachePath;
}
diff --git a/src/SimpleSAML/SessionHandler.php b/src/SimpleSAML/SessionHandler.php
index 961b722d0b..2974f1d58b 100644
--- a/src/SimpleSAML/SessionHandler.php
+++ b/src/SimpleSAML/SessionHandler.php
@@ -164,7 +164,7 @@ public function getCookieParams(): array
'lifetime' => $config->getOptionalInteger('session.cookie.lifetime', 0),
'path' => $config->getOptionalString('session.cookie.path', '/'),
'domain' => $config->getOptionalString('session.cookie.domain', null),
- 'secure' => $config->getOptionalBoolean('session.cookie.secure', $httpUtils->isHTTPS()),
+ 'secure' => $config->getOptionalBoolean('session.cookie.secure', $httpUtils->isSecureCookieAllowed()),
'samesite' => $config->getOptionalString('session.cookie.samesite', null),
'httponly' => true,
];
diff --git a/src/SimpleSAML/SessionHandlerPHP.php b/src/SimpleSAML/SessionHandlerPHP.php
index 99931bd001..d7e6e42ad5 100644
--- a/src/SimpleSAML/SessionHandlerPHP.php
+++ b/src/SimpleSAML/SessionHandlerPHP.php
@@ -190,8 +190,8 @@ public function getCookieSessionId(): ?string
$session_cookie_params = session_get_cookie_params();
$httpUtils = new Utils\HTTP();
- if ($session_cookie_params['secure'] && !$httpUtils->isHTTPS()) {
- throw new Error\Exception('Session start with secure cookie not allowed on http.');
+ if ($session_cookie_params['secure'] && !$httpUtils->isSecureCookieAllowed()) {
+ throw new Error\Exception('Session start with secure cookie not allowed on http (except on localhost).');
}
@session_start();
@@ -322,9 +322,9 @@ public function setCookie(string $sessionName, ?string $sessionID, ?array $cooki
}
$httpUtils = new Utils\HTTP();
- if ($cookieParams['secure'] && !$httpUtils->isHTTPS()) {
+ if ($cookieParams['secure'] && !$httpUtils->isSecureCookieAllowed()) {
throw new Error\CannotSetCookie(
- 'Setting secure cookie on plain HTTP is not allowed.',
+ 'Setting secure cookie on plain HTTP (except on localhost) is not allowed.',
Error\CannotSetCookie::SECURE_COOKIE,
);
}
diff --git a/src/SimpleSAML/Store/SQLStore.php b/src/SimpleSAML/Store/SQLStore.php
index 7597139d42..21e37239f4 100644
--- a/src/SimpleSAML/Store/SQLStore.php
+++ b/src/SimpleSAML/Store/SQLStore.php
@@ -78,6 +78,7 @@ public function __construct()
throw new Exception("Database error: " . $e->getMessage());
}
$this->pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
+ $this->pdo->setAttribute(PDO::ATTR_EMULATE_PREPARES, false);
$this->driver = $this->pdo->getAttribute(PDO::ATTR_DRIVER_NAME);
@@ -159,7 +160,7 @@ private function initTableVersionTable(): void
*/
$update = [
'CREATE TABLE ' . $this->prefix .
- '_tableVersion (_name VARCHAR(30) PRIMARY KEY NOT NULL, _version INTEGER NOT NULL)',
+ '_tableVersion_new (_name VARCHAR(30) PRIMARY KEY NOT NULL, _version INTEGER NOT NULL)',
'INSERT INTO ' . $this->prefix . '_tableVersion_new SELECT * FROM ' .
$this->prefix . '_tableVersion',
'DROP TABLE ' . $this->prefix . '_tableVersion',
diff --git a/tests/modules/saml/src/IdP/SAML2Test.php b/tests/modules/saml/src/IdP/SAML2Test.php
index ffcbf59d97..9e51018cec 100644
--- a/tests/modules/saml/src/IdP/SAML2Test.php
+++ b/tests/modules/saml/src/IdP/SAML2Test.php
@@ -262,6 +262,20 @@ private function idpMetadataHandlerHelper(array $metadata, array $extraconfig =
return SAML2::getHostedMetadata($metadata['entityid']);
}
+
+ /**
+ * Test that an override for the errorURL produced the expected output.
+ */
+ public function testIdPGetHostedMetadataErrorUrlOverride(): void
+ {
+ $md = [
+ 'errorURL' => 'https://simplesamlphp.org',
+ ];
+ $hostedMd = $this->idpMetadataHandlerHelper($md);
+ $this->assertEquals('https://simplesamlphp.org', $hostedMd['errorURL']);
+ }
+
+
/**
* A minimally configured hosted IdP has all default fields with expected values.
*/
diff --git a/tests/src/SimpleSAML/Auth/StateTest.php b/tests/src/SimpleSAML/Auth/StateTest.php
index dd7744e3b4..08a2293b50 100644
--- a/tests/src/SimpleSAML/Auth/StateTest.php
+++ b/tests/src/SimpleSAML/Auth/StateTest.php
@@ -24,7 +24,7 @@ public function testGetPersistentAuthData(): void
'Attributes' => [],
'Expire' => 1234,
'LogoutState' => 'logoutState',
- 'AuthInstant' => 123456,
+ 'AuthnInstant' => 123456,
'RememberMe' => true,
'saml:sp:NameID' => 'nameID',
];
diff --git a/src/SimpleSAML/Utils/HTTP.php b/src/SimpleSAML/Utils/HTTP.php
index 9189d3bf7c..f6c7616ceb 100644
--- a/src/SimpleSAML/Utils/HTTP.php
+++ b/src/SimpleSAML/Utils/HTTP.php
@@ -1099,15 +1099,15 @@ public function setCookie(string $name, ?string $value, ?array $params = null, b
$params = $default_params;
}
- // Do not set secure cookie if not on HTTPS
- if ($params['secure'] && !$this->isHTTPS()) {
+ // Do not set secure cookie if not on HTTPS or localhost
+ if ($params['secure'] && !$this->isSecureCookieAllowed()) {
if ($throw) {
throw new Error\CannotSetCookie(
- 'Setting secure cookie on plain HTTP is not allowed.',
+ 'Setting secure cookie on plain HTTP (except on localhost) is not allowed.',
Error\CannotSetCookie::SECURE_COOKIE,
);
}
- Logger::warning('Error setting cookie: setting secure cookie on plain HTTP is not allowed.');
+ Logger::warning('Error setting cookie: setting secure cookie on plain HTTP (except on localhost) is not allowed.');
return;
}
@@ -1164,6 +1164,17 @@ public function setCookie(string $name, ?string $value, ?array $params = null, b
}
+ /**
+ * Check if "Secure" attribute on cookies is supported
+ *
+ * @return boolean True "Secure" attribute can be set, false otherwise.
+ */
+ public function isSecureCookieAllowed(): bool
+ {
+ return $this->isHTTPS() || in_array($this->getSelfHost(), ['localhost', '127.0.0.1', '::1'], true);
+ }
+
+
/**
* Submit a POST form to a specific destination.
*